==> pointpos_api-0.0.13.tar.gz: lib/api/item_api.dart <==
import 'package:jaguar_retrofit/annotations/annotations.dart';
import 'package:jaguar_retrofit/jaguar_retrofit.dart';
import 'package:jaguar_serializer/jaguar_serializer.dart';
import 'package:jaguar_mimetype/jaguar_mimetype.dart';
import 'dart:async';

import 'package:pointpos_api/model/exception.dart';
import 'package:pointpos_api/model/item.dart';

part 'item_api.jretro.dart';

@GenApiClient()
class ItemApi extends ApiClient with _$ItemApiClient {
    final Route base;
    final Map<String, CodecRepo> converters;
    final Duration timeout;

    ItemApi({this.base, this.converters, this.timeout = const Duration(minutes: 2)});

    /// Create Item
    ///
    /// Create Item
    @PostReq(path: "/item", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<Item> createItem(
        
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey
            ,
             @AsJson() Item body
        ) {
        return super.createItem(
        
        authorization, 
        
        xAPIKey

        ,
        body
        ).timeout(timeout);
    }

    /// Create Item Image
    ///
    /// Create Item Image
    @PostReq(path: "/item/:id/image", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<Item> createItemImage(
            @PathParam("id") String id
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey
            ,
            @AsMultipartField() MultipartFile file, 
            
            @AsMultipartField() bool isMain
        ) {
        return super.createItemImage(
        id
        ,
        authorization, 
        
        xAPIKey

        ,
        file, 
        
        isMain
        ).timeout(timeout);
    }

    /// Delete Item By ID
    ///
    /// Delete Item By ID
    @DeleteReq(path: "/item/:id", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<void> deleteItemByID(
            @PathParam("id") String id
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey
        ) {
        return super.deleteItemByID(
        id
        ,
        authorization, 
        
        xAPIKey

        ).timeout(timeout);
    }

    /// Delete Item Image By ID
    ///
    /// Delete Item Image By ID
    @DeleteReq(path: "/item/:id/image/:imageId", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<void> deleteItemImageByID(
            @PathParam("id") String id, 
            @PathParam("imageId") String imageId
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey
        ) {
        return super.deleteItemImageByID(
        id, 
        imageId
        ,
        authorization, 
        
        xAPIKey

        ).timeout(timeout);
    }

    /// Get Item List
    ///
    /// Get Item  List
    @GetReq(path: "/item", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<List<Item>> findItem(
        
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey
        ,
            @QueryParam("limit") num limit, 
        
            @QueryParam("offset") num offset, 
        
            @QueryParam("sort") String sort, 
        
            @QueryParam("direction") String direction, 
        
            @QueryParam("filter") List<String> filter
        ) {
        return super.findItem(
        
        authorization, 
        
        xAPIKey
        ,
        limit, 
        
        offset, 
        
        sort, 
        
        direction, 
        
        filter

        ).timeout(timeout);
    }

    /// Get Item By ID
    ///
    /// Get Item By ID
    @GetReq(path: "/item/:id", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<Item> getItemByID(
            @PathParam("id") String id
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey
        ) {
        return super.getItemByID(
        id
        ,
        authorization, 
        
        xAPIKey

        ).timeout(timeout);
    }

    /// Update Item By ID
    ///
    /// Update [object Object] By ID
    @PutReq(path: "/item/:id", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<Item> updateItemByID(
            @PathParam("id") String id
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey
            ,
             @AsJson() Item body
        ) {
        return super.updateItemByID(
        id
        ,
        authorization, 
        
        xAPIKey

        ,
        body
        ).timeout(timeout);
    }

    /// Update Item Image By ID
    ///
    /// Update Item Image By ID
    @PutReq(path: "/item/:id/image/:imageId", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<Item> updateItemImageByID(
            @PathParam("id") String id, 
            @PathParam("imageId") String imageId
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey
            ,
            @AsMultipartField() MultipartFile file, 
            
            @AsMultipartField() bool isMain
        ) {
        return super.updateItemImageByID(
        id, 
        imageId
        ,
        authorization, 
        
        xAPIKey

        ,
        file, 
        
        isMain
        ).timeout(timeout);
    }


}

==> pointpos_api-0.0.16.tar.gz: lib/api/item_api.dart <==
import 'package:jaguar_retrofit/annotations/annotations.dart';
import 'package:jaguar_retrofit/jaguar_retrofit.dart';
import 'package:jaguar_serializer/jaguar_serializer.dart';
import 'package:jaguar_mimetype/jaguar_mimetype.dart';
import 'dart:async';

import 'package:pointpos_api/model/exception.dart';
import 'package:pointpos_api/model/item.dart';

part 'item_api.jretro.dart';

@GenApiClient()
class ItemApi extends ApiClient with _$ItemApiClient {
    final Route base;
    final Map<String, CodecRepo> converters;
    final Duration timeout;

    ItemApi({this.base, this.converters, this.timeout = const Duration(minutes: 2)});

    /// Create Item
    ///
    /// Create Item
    @PostReq(path: "/item", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<Item> createItem(
        
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
            ,
             @AsJson() Item body
        ) {
        return super.createItem(
        
        authorization, 
        
        xAPIKey, 
        
        xPin

        ,
        body
        ).timeout(timeout);
    }

    /// Create Item Image
    ///
    /// Create Item Image
    @PostReq(path: "/item/:id/image", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<Item> createItemImage(
            @PathParam("id") String id
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
            ,
            @AsMultipartField() MultipartFile file, 
            
            @AsMultipartField() bool isMain
        ) {
        return super.createItemImage(
        id
        ,
        authorization, 
        
        xAPIKey, 
        
        xPin

        ,
        file, 
        
        isMain
        ).timeout(timeout);
    }

    /// Delete Item By ID
    ///
    /// Delete Item By ID
    @DeleteReq(path: "/item/:id", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<void> deleteItemByID(
            @PathParam("id") String id
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
        ) {
        return super.deleteItemByID(
        id
        ,
        authorization, 
        
        xAPIKey, 
        
        xPin

        ).timeout(timeout);
    }

    /// Delete Item Image By ID
    ///
    /// Delete Item Image By ID
    @DeleteReq(path: "/item/:id/image/:imageId", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<void> deleteItemImageByID(
            @PathParam("id") String id, 
            @PathParam("imageId") String imageId
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
        ) {
        return super.deleteItemImageByID(
        id, 
        imageId
        ,
        authorization, 
        
        xAPIKey, 
        
        xPin

        ).timeout(timeout);
    }

    /// Get Item List
    ///
    /// Get Item  List
    @GetReq(path: "/item", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<List<Item>> findItem(
        
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
        ,
            @QueryParam("limit") num limit, 
        
            @QueryParam("offset") num offset, 
        
            @QueryParam("sort") String sort, 
        
            @QueryParam("direction") String direction, 
        
            @QueryParam("filter") List<String> filter
        ) {
        return super.findItem(
        
        authorization, 
        
        xAPIKey, 
        
        xPin
        ,
        limit, 
        
        offset, 
        
        sort, 
        
        direction, 
        
        filter

        ).timeout(timeout);
    }

    /// Get Item By ID
    ///
    /// Get Item By ID
    @GetReq(path: "/item/:id", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<Item> getItemByID(
            @PathParam("id") String id
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
        ) {
        return super.getItemByID(
        id
        ,
        authorization, 
        
        xAPIKey, 
        
        xPin

        ).timeout(timeout);
    }

    /// Update Item By ID
    ///
    /// Update [object Object] By ID
    @PutReq(path: "/item/:id", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<Item> updateItemByID(
            @PathParam("id") String id
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
            ,
             @AsJson() Item body
        ) {
        return super.updateItemByID(
        id
        ,
        authorization, 
        
        xAPIKey, 
        
        xPin

        ,
        body
        ).timeout(timeout);
    }

    /// Update Item Image By ID
    ///
    /// Update Item Image By ID
    @PutReq(path: "/item/:id/image/:imageId", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<Item> updateItemImageByID(
            @PathParam("id") String id, 
            @PathParam("imageId") String imageId
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
            ,
            @AsMultipartField() MultipartFile file, 
            
            @AsMultipartField() bool isMain
        ) {
        return super.updateItemImageByID(
        id, 
        imageId
        ,
        authorization, 
        
        xAPIKey, 
        
        xPin

        ,
        file, 
        
        isMain
        ).timeout(timeout);
    }


}
